CustomLocalization class

Constructors

CustomLocalization(Map<String, String> _entries)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key, {Map<String, dynamic>? params}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

delegate CustomLocalizationDelegate
final

Static Methods

of(BuildContext context) CustomLocalization?